{% extends 'django_spire/auth/page/auth_page.html' %}

{% load static %}

{% block base_title %}Password Reset Form {% endblock %}

{% block authentication_page_content %}
    <h3>Password Reset</h3>
    <form x-data="{
        new_password1: new GlueCharField('new_password1', {required: true}),
        new_password2: new GlueCharField('new_password2', {required: true})
    }" method="post" class="text-app-secondary">
        {% csrf_token %}
        <div class="row">
            <div class="col">
                {% include 'django_glue/form/field/password_field.html' with glue_field='new_password1' %}
            </div>
        </div>
        <div class="row mt-2">
            <div class="col">
                {% include 'django_glue/form/field/password_field.html' with glue_field='new_password2' %}
            </div>
        </div>
        <div class="row mt-2">
            <div class="col">
                <button type="submit" class="w-100 btn btn-app-primary bg-app-primary mt-2">Submit</button>
            </div>
        </div>
    </form>
{% endblock %}
