# Generated by Django 5.2 on 2025-05-17 23:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_spire_ai_chat', '0003_rename__content_chatmessage__intel_data_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='chatmessage',
            name='response_type',
            field=models.CharField(choices=[('request', 'Request'), ('response', 'Response'), ('loading_response', 'Loading Response')], default='request', max_length=32),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='chatmessage',
            name='sender',
            field=models.CharField(default='', max_length=128),
            preserve_default=False,
        ),
    ]
