<div class="row justify-content-center align-items-center item-row item-hover border rounded-2 border-300 bg-light-purple py-1 mx-2 my-2">
    <div class="col-12">
        <div class="row g-1">
            <div class="col">
                <div class="text-muted font-weight-bold">
                    <span class="fs--2">
                        {{ comment.user.get_full_name|title }}
                        <span class="text-400">
                            posted: {{ comment.date_statistic_created }}
                        </span>
                    </span>
                </div>
            </div>
            <div class="col-auto text-end">
                {% if comment.user == request.user %}
                    {% if comment_edit_url_name %}
                        {% grouping_url comment_edit_url_name object_pk=model.pk pk=comment.pk as comment_edit_url %}
                    {% endif %}
                    {% if comment_delete_url_name %}
                        {% grouping_url comment_delete_url_name object_pk=model.pk pk=comment.pk as comment_delete_url %}
                    {% endif %}
                    {% include 'django_spire/element/dropdown_table_element.html' with dropdown_icon='fas fa-ellipsis-h' edit_url=comment_edit_url delete_url=comment_delete_url %}
                {% endif %}
            </div>
        </div>
    </div>
    <div class="col pb-1">
        <span>{{ comment.information | linebreaksbr }}</span>
    </div>
</div>
