{% extends 'django_spire/card/title_card.html' %}

{% block card_padding_class %}p-0{% endblock %}

{% block card_title %}
    Permissions
{% endblock %}

{% block card_title_content %}
    {% for perm_data in permission_data %}
        {% include 'django_spire/permission/item/../item/group_perm_item.html' %}
    {% endfor %}
{% endblock %}
