.item-select:hover {
    background-color: var(--app-primary);
    cursor: pointer;
}

.item-container:first-child {
    padding-top: 0 !important;
}

.item-container:last-child {
    padding-bottom: 0 !important;
    border: none !important;
}

.no-select {
    user-select: none;
}

.tab-item::after{
    content: "";
    position: absolute;
    bottom: -1px;
    left: 0;
    width: 100%;
    height: 1px;
    background-color: var(--app-primary);
}

.w-side-navigation {
    width: var(--app-side-navigation-width);
}

.w-side-navigation-img {
    width: calc(var(--app-side-navigation-width) - 20px);
}

.w-mobile-navigation {
    width: var(--app-mobile-navigation-width);
}

.w-mobile-navigation-img {
    width: calc(var(--app-mobile-navigation-width) - 20px);
}
