# Generated by Django 5.2.2 on 2025-06-11 21:04

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_spire_notification_sms', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='SmsTemporaryMedia',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content', models.TextField()),
                ('content_type', models.CharField(choices=[('image/png', 'Png'), ('image/jpeg', 'Jpeg')], max_length=64)),
                ('name', models.CharField(max_length=255)),
                ('expire_datetime', models.DateTimeField()),
                ('external_access_key', models.UUIDField(unique=True)),
            ],
            options={
                'verbose_name': 'SMS Temporary Media',
                'verbose_name_plural': 'SMS Temporary Media',
                'db_table': 'django_spire_notification_sms_temporary_media',
            },
        ),
        migrations.AddField(
            model_name='smsnotification',
            name='media_url',
            field=models.URLField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='smsnotification',
            name='temporary_media',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='sms_notifications', related_query_name='sms_notification', to='django_spire_notification_sms.smstemporarymedia'),
        ),
    ]
