<footer class="mt-auto bg-light py-3">
    {% block footer_content %}
        <div class="container text-center">
            <span class="text-muted">
                <span class="fw-bold">Django Spire</span>. &copy; All Rights Reserved to Stratus ADV. 2024
            </span>
        </div>
    {% endblock %}
</footer>
