{% extends 'django_spire/item/item.html' %}

{% block item_title %}
    {% url 'user_account:detail' pk=user.pk as detail_url %}
    {% include 'django_spire/element/attribute_element.html' with attribute_type='User' attribute_value=user.get_full_name attribute_href=detail_url %}
{% endblock %}

{% block item_row_content %}
    <div class="col">
        {% include 'django_spire/element/attribute_element.html' with attribute_type='Email' attribute_value=user.email %}
    </div>

    <div class="col">
        {% include 'django_spire/element/attribute_element.html' with attribute_type='Status' %}
        {% include 'django_spire/user_account/element/../element/is_active_badge.html' with is_active=user.is_active %}
    </div>
{% endblock %}
