{% extends 'django_spire/dropdown/dropdown.html' %}

{% block dropdown_position %}end-0 top-100{% endblock %}

{% block dropdown_trigger %}
    <span
        class="bi bi-three-dots-vertical"
        x-bind="trigger"
    >
    </span>
{% endblock %}

{% block dropdown_content %}
    {% include 'django_spire/dropdown/element/dropdown_link_element.html' with x_click="enable_rename_chat()" link_text='Rename' %}

    {% url 'django_spire:ai:chat:template:confirm_delete' pk=recent_chat.id as delete_url %}
    {% include 'django_spire/dropdown/element/ellipsis_dropdown_modal_link_element.html' with view_url=delete_url link_text='Delete' link_css='text-app-danger' %}
{% endblock %}
