:root {
    --app-a-primary: var(--app-primary);
}

a {
    color: var(--app-a-primary) !important;
    text-decoration: none;
}

body {
    font-family: 'Karla-Bold', sans-serif !important;
    font-weight: 500 !important;
}

h1, h2, h3, h4, h5, h6 {
    font-family: 'Merriweather', serif !important;
    font-weight: 600 !important;
}

.card {
    box-shadow: rgba(0, 0, 0, 0.1) 0 0.25rem 0.375rem -0.0625rem, rgba(0, 0, 0, 0.06) 0 0.125rem 0.25rem -0.0625rem !important;
}

.cursor-pointer {
    cursor: pointer !important;
}

.darken-background {
    position: relative;
}

.darken-background:after {
    content: " ";
    z-index: 1024;
    display: block;
    position: absolute;
    height: 100%;
    top: 0;
    left: 0;
    right: 0;
    transition: background-color 0.5s ease;
    background: rgba(0, 0, 0, 0.5);
}

.fs--1 {
    font-size: .80rem !important;
}

.fs--2 {
    font-size: .75rem !important;
}

.fs-7 {
    font-size: .85rem !important;
}

.fw-400 {
    font-weight: 400 !important;
}

.modal-overlay {
    background-color: rgba(0, 0, 0, 0.5);
}

.ms-6 {
    margin-left: 6rem !important;
}

.me-6 {
    margin-right: 6rem !important;
}

.mt-6 {
    margin-top: 6rem !important;
}

.mb-6 {
    margin-bottom: 6rem !important;
}

.my-6 {
    margin-top: 6rem !important;
    margin-bottom: 6rem !important;
}

.ms-n1 {
    margin-left: -.25rem !important
}

.ms-n2 {
    margin-left: -.5rem !important
}

.ms-n3 {
    margin-left: -1rem !important
}

.ms-n4 {
    margin-left: -1.5rem !important
}

.ms-n5 {
    margin-left: -3rem !important
}

.ms-n6 {
    margin-left: -6rem !important;
}

.me-n1 {
    margin-right: -.25rem !important
}

.me-n2 {
    margin-right: -.5rem !important
}

.me-n3 {
    margin-right: -1rem !important
}

.me-n4 {
    margin-right: -1.5rem !important
}

.me-n5 {
    margin-right: -3rem !important
}

.me-n6 {
    margin-right: -6rem !important;
}

.mt-n1 {
    margin-top: -.25rem !important
}

.mt-n2 {
    margin-top: -.5rem !important
}

.mt-n3 {
    margin-top: -1rem !important
}

.mt-n4 {
    margin-top: -1.5rem !important
}

.mt-n5 {
    margin-top: -3rem !important
}

.mt-n6 {
    margin-top: -6rem !important;
}

.mb-n1 {
    margin-bottom: -.25rem !important
}

.mb-n2 {
    margin-bottom: -.5rem !important
}

.mb-n3 {
    margin-bottom: -1rem !important
}

.mb-n4 {
    margin-bottom: -1.5rem !important
}

.mb-n5 {
    margin-bottom: -3rem !important
}

.mb-n6 {
    margin-bottom: -6rem !important;
}

.overlay {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    background-color: rgba(0, 0, 0, 0.5);
    z-index: 1040;
    transition: opacity 0.3s ease-in-out;
}

.ps-6 {
    padding-left: 6rem !important;
}

.pe-6 {
    padding-right: 6rem !important;
}

.pt-6 {
    padding-top: 6rem !important;
}

.pb-6 {
    padding-bottom: 6rem !important;
}

.py-6 {
    padding-top: 6rem !important;
    padding-bottom: 6rem !important;
}

.scrollbar-hidden::-webkit-scrollbar {
    display: none;
}

.scrollbar-hidden {
  -ms-overflow-style: none;  /* IE and Edge */
  scrollbar-width: none;  /* Firefox */
}

.sidebar {
    position: fixed;
    top: 0;
    right: 0;
    height: 100%;
    overflow-x: hidden;
    transition: transform 0.5s ease-in-out;
    z-index: 1041;
    background-color: #fff;
    transform: translateX(100%);
    width: 250px;
}

.sidebar.show {
    transform: translateX(0);
}

.text-200 {
    font-weight: 200 !important;
}

.text-300 {
    font-weight: 300 !important;
}

.text-400 {
    font-weight: 400 !important;
}

.text-500 {
    font-weight: 500 !important;
}

.text-600 {
    font-weight: 600 !important;
}

.text-700 {
    font-weight: 700 !important;
}

.text-800 {
    font-weight: 800 !important;
}

.text-900 {
    font-weight: 900 !important;
}

.text-400 {
    font-weight: 400 !important;
}

.video-container {
    overflow: hidden;
    position: relative;
    width: 100%;
}

.video-container::after {
    padding-top: 56.25%;
    display: block;
    content: '';
}

.video-container iframe {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
}

[x-cloak] {
    display: none !important;
}

@media (max-width: 767px) {
    .ms-sm-n1 {
        margin-left: -.25rem !important
    }

    .ms-sm-n2 {
        margin-left: -.5rem !important
    }

    .ms-sm-n3 {
        margin-left: -1rem !important
    }

    .ms-sm-n4 {
        margin-left: -1.5rem !important
    }

    .ms-sm-n5 {
        margin-left: -3rem !important
    }

    .ms-sm-n6 {
        margin-left: -6rem !important;
    }

    .ms-sm-6 {
        margin-left: 6rem !important;
    }

    .me-sm-6 {
        margin-right: 6rem !important;
    }

    .mt-sm-6 {
        margin-top: 6rem !important;
    }

    .mb-sm-6 {
        margin-bottom: 6rem !important;
    }

    .my-sm-6 {
        margin-top: 6rem !important;
        margin-bottom: 6rem !important;
    }

    .ps-sm-6 {
        padding-left: 6rem !important;
    }

    .pe-sm-6 {
        padding-right: 6rem !important;
    }

    .pt-sm-6 {
        padding-top: 6rem !important;
    }

    .pb-sm-6 {
        padding-bottom: 6rem !important;
    }

    .py-sm-6 {
        padding-top: 6rem !important;
        padding-bottom: 6rem !important;
    }

    .position-sm-static {
        position: static !important;
    }

    .position-sm-relative {
        position: relative !important;
    }

    .position-sm-absolute {
        position: absolute !important;
    }

    .position-sm-fixed {
        position: fixed !important;
    }

    .position-sm-sticky {
        position: sticky !important;
    }

    .w-sm-25 {
        width: 25%;
    }

    .w-sm-50 {
        width: 50%;
    }

    .w-sm-75 {
        width: 75%;
    }

    .w-sm-100 {
        width: 100%;
    }
}

@media (min-width: 768px) {
    .ms-md-n1 {
        margin-left: -.25rem !important
    }

    .ms-md-n2 {
        margin-left: -.5rem !important
    }

    .ms-md-n3 {
        margin-left: -1rem !important
    }

    .ms-md-n4 {
        margin-left: -1.5rem !important
    }

    .ms-md-n5 {
        margin-left: -3rem !important
    }

    .ms-md-n6 {
        margin-left: -6rem !important;
    }

    .ms-md-6 {
        margin-left: 6rem !important;
    }

    .me-md-6 {
        margin-right: 6rem !important;
    }

    .mt-md-6 {
        margin-top: 6rem !important;
    }

    .mb-md-6 {
        margin-bottom: 6rem !important;
    }

    .my-md-6 {
        margin-top: 6rem !important;
        margin-bottom: 6rem !important;
    }

    .ps-md-6 {
        padding-left: 6rem !important;
    }

    .pe-md-6 {
        padding-right: 6rem !important;
    }

    .pt-md-6 {
        padding-top: 6rem !important;
    }

    .pb-md-6 {
        padding-bottom: 6rem !important;
    }

    .py-md-6 {
        padding-top: 6rem !important;
        padding-bottom: 6rem !important;
    }

    .position-md-static {
        position: static !important;
    }

    .position-md-relative {
        position: relative !important;
    }

    .position-md-absolute {
        position: absolute !important;
    }

    .position-md-fixed {
        position: fixed !important;
    }

    .position-md-sticky {
        position: sticky !important;
    }

    .w-md-25 {
        width: 25%;
    }

    .w-md-50 {
        width: 50%;
    }

    .w-md-75 {
        width: 75%;
    }

    .w-md-100 {
        width: 100%;
    }

}

@media (min-width: 992px) {
    .ms-lg-n1 {
        margin-left: -.25rem !important
    }

    .ms-lg-n2 {
        margin-left: -.5rem !important
    }

    .ms-lg-n3 {
        margin-left: -1rem !important
    }

    .ms-lg-n4 {
        margin-left: -1.5rem !important
    }

    .ms-lg-n5 {
        margin-left: -3rem !important
    }

    .ms-lg-n6 {
        margin-left: -6rem !important;
    }

    .ps-lg-6 {
        padding-left: 6rem !important;
    }

    .pe-lg-6 {
        padding-right: 6rem !important;
    }

    .pt-lg-6 {
        padding-top: 6rem !important;
    }

    .pb-lg-6 {
        padding-bottom: 6rem !important;
    }

    .py-lg-6 {
        padding-top: 6rem !important;
        padding-bottom: 6rem !important;
    }

    .ms-lg-6 {
        margin-left: 6rem !important;
    }

    .me-lg-6 {
        margin-right: 6rem !important;
    }

    .mt-lg-6 {
        margin-top: 6rem !important;
    }

    .mb-lg-6 {
        margin-bottom: 6rem !important;
    }

    .my-lg-6 {
        margin-top: 6rem !important;
        margin-bottom: 6rem !important;
    }

    .position-lg-static {
        position: static !important;
    }

    .position-lg-relative {
        position: relative !important;
    }

    .position-lg-absolute {
        position: absolute !important;
    }

    .position-lg-fixed {
        position: fixed !important;
    }

    .position-lg-sticky {
        position: sticky !important;
    }

    .w-lg-25 {
        width: 25%;
    }

    .w-lg-50 {
        width: 50%;
    }

    .w-lg-75 {
        width: 75%;
    }

    .w-lg-100 {
        width: 100%;
    }
}

@media (min-width: 1200px) {
    .position-xl-static {
        position: static !important;
    }

    .position-xl-relative {
        position: relative !important;
    }

    .position-xl-absolute {
        position: absolute !important;
    }

    .position-xl-fixed {
        position: fixed !important;
    }

    .position-xl-sticky {
        position: sticky !important;
    }

    .w-xl-25 {
        width: 25%;
    }

    .w-xl-50 {
        width: 50%;
    }

    .w-xl-75 {
        width: 75%;
    }

    .w-xl-100 {
        width: 100%;
    }
}
