{% extends 'django_spire/card/title_card.html' %}

{% load spire_core_tags %}

{% block card_title %}
    Users
{% endblock %}

{% block card_button %}
    {% if perms.permission.change_portalgroup %}
        {% url 'permission:group_user_form' pk=group.pk as group_user_form %}
        {% include 'django_spire/button/primary_dark_button.html' with button_href=group_user_form button_icon='bi bi-plus-lg' %}
    {% endif %}
{% endblock %}

{% block card_title_content %}
    {% for user in user_list %}
        {% include 'django_spire/permission/item/../item/group_user_item.html' with small_view=True %}
    {% empty %}
        {% include 'django_spire/item/no_data_item.html' %}
    {% endfor %}
{% endblock %}
