{% extends 'django_spire/page/full_page.html' %}

{% block full_page_content %}
    <form method="post">
        {% csrf_token %}
        <div class="row justify-content-center">
            <div class="col-10">
                {% include 'django_spire/user_account/card/../card/register_user_detail_form_card.html' %}
            </div>
{#            <div class="col-4">#}
{#                {% include 'django_spire/permission/card/permission_user_groups_form_card.html' %}#}
{#            </div>#}
        </div>
    </form>
{% endblock %}
