{% extends 'django_spire/page/full_page.html' %}

{% block full_page_content %}
    <div class="row">
        <div class="col">
            {% include 'django_spire/user_account/card/../card/user_list_card.html' with queryset=user_list %}
        </div>
    </div>
{% endblock %}
