# Generated by Django 5.2.1 on 2025-05-23 16:00

import django.db.models.deletion
import django.utils.timezone
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='HelpDeskTicket',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.BooleanField(default=True, editable=False)),
                ('is_deleted', models.BooleanField(default=False, editable=False)),
                ('created_datetime', models.DateTimeField(default=django.utils.timezone.localtime, editable=False)),
                ('purpose', models.CharField(choices=[('app', 'App'), ('comp', 'Company')], max_length=4, verbose_name='Purpose')),
                ('priority', models.CharField(choices=[('low', 'Low'), ('med', 'Medium'), ('high', 'High'), ('urge', 'Urgent')], max_length=4, verbose_name='Priority')),
                ('status', models.CharField(choices=[('read', 'Ready'), ('prog', 'In Progress'), ('done', 'Done')], default='read', max_length=4, verbose_name='Status')),
                ('description', models.TextField()),
                ('created_by', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, related_name='created_help_desk_tickets', related_query_name='created_help_desk_ticket', to=settings.AUTH_USER_MODEL, verbose_name='Created By')),
            ],
            options={
                'verbose_name': 'Help Desk Ticket',
                'verbose_name_plural': 'Help Desk Tickets',
                'db_table': 'django_spire_help_desk_ticket',
            },
        ),
    ]
