{% if ticket.status == 'read'  %}
    {% include 'django_spire/badge/secondary_badge.html' with badge_text=ticket.get_status_display %}
{% elif ticket.status == 'prog' %}
    {% include 'django_spire/badge/primary_badge.html' with badge_text=ticket.get_status_display %}
{% elif ticket.status == 'done' %}
    {% include 'django_spire/badge/success_badge.html' with badge_text=ticket.get_status_display %}
{% endif %}